@@ -1,10 +1,10 @@
-# $Id: config.rb,v 1.71 2005/07/14 03:31:31 fdiary Exp $
+# $Id: config.rb,v 1.81 2005/08/03 23:40:11 fdiary Exp $
 # Copyright (C) 2004-2005 Kazuhiko <kazuhiko@fdiary.net>
 #
 # TADA Tadashi <sho@spc.gr.jp> holds the copyright of Config class.
 
-HIKI_VERSION  = '0.8.1'
-HIKI_RELEASE_DATE = '2005-07-14'
+HIKI_VERSION  = '0.8.3'
+HIKI_RELEASE_DATE = '2005-08-04'
 
 require 'cgi'
 require 'hiki/command'
@@ -75,8 +75,9 @@ module Hiki
     end
 
     def save_config
+      conf = ERB::new( File::open( "#{@template_path}/hiki.conf" ){|f| f.read }.untaint ).result( binding )
       File::open(@config_file, "w") do |f|
-        f.print ERB::new( File::open( "#{@template_path}/hiki.conf" ){|f| f.read }.untaint ).result( binding )
+        f.print conf
       end
     end
 
@@ -84,7 +85,7 @@ module Hiki
       unless @base_url
         if !ENV['SCRIPT_NAME']
           @base_url = ''
-        elsif ENV['HTTPS']
+        elsif ENV['HTTPS'] && /off/i !~ ENV['HTTPS']
           port = (ENV['SERVER_PORT'] == '443') ? '' : ':' + ENV['SERVER_PORT'].to_s
           @base_url = "https://#{ ENV['SERVER_NAME'] }#{ port }#{File::dirname(ENV['SCRIPT_NAME'])}/".sub(%r|/+$|, '/')
         else
@@ -129,8 +130,8 @@ module Hiki
 
       # default values
       @smtp_server   ||= 'localhost'
-      @use_plugin    ||= false
-      @site_name     ||= 'hoge hoge'
+      @use_plugin      = true if @use_plugin.nil?
+      @site_name     ||= 'Hiki'
       @author_name   ||= ''
       @mail_on_update||= false
       @mail          ||= ''
@@ -143,16 +144,17 @@ module Hiki
       @auto_link     ||= false
       @cache_path    ||= "#{@data_path}/cache"
       @style         ||= 'default'
-      @hilight_keys  ||= true
+      @hilight_keys    = true if @hilight_keys.nil?
       @plugin_debug  ||= false
       @charset       ||= 'EUC-JP'
       @database_type ||= 'flatfile'
-      @cgi_name      ||= './'
+      @cgi_name        = './' if !@cgi_name || @cgi_name.empty?
       @admin_name    ||= 'admin'
       @repos_type    ||= 'default'
       @use_wikiname    = true if @use_wikiname.nil?
       @options         = {} unless @options.class == Hash
 
+      @xmlrpc_enabled  ||= true
 
       @template_path   ||= "#{PATH}/template"
       @plugin_path     ||= "#{PATH}/plugin"
@@ -199,7 +201,7 @@ module Hiki
       variables = [:site_name, :author_name, :mail, :theme, :password,
                    :theme_url, :sidebar_class, :main_class, :theme_path,
                    :mail_on_update, :use_sidebar, :auto_link, :use_wikiname,
-                   :options2]
+                   :xmlrpc_enabled, :options2]
       begin
         cgi_conf = File::open( @config_file ){|f| f.read }.untaint
         cgi_conf.gsub!( /^[@$]/, '' )
