@@ -1,4 +1,4 @@
-# $Id: interwiki.rb,v 1.5 2004/02/15 02:48:35 hitoshi Exp $
+# $Id: interwiki.rb,v 1.9 2005/06/28 05:39:08 fdiary Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 module Hiki
@@ -6,16 +6,16 @@ module Hiki
     require 'hiki/util'
     
     URL  = '(?:http|https|ftp|mailto|file):[a-zA-Z0-9;/?:@&=+$,\-_.!~*\'()#%]+'
-    INTERWIKI_NAME_RE =  /\[\[([^|]+)\|(#{URL})\]\](?:\s+(sjis|euc|alias))?/
+    INTERWIKI_NAME_RE =  /\[\[([^|]+)\|(#{URL})\]\](?:\s+(sjis|euc|utf8|alias))?/
 
     attr_reader :interwiki_names
     
-    def initialize(db, plugin)
-      @db = db
-      @plugin = plugin
+    def initialize( str )
       @interwiki_names = Hash::new
-      
-      load_interwiki_names
+      (str || '').scan( INTERWIKI_NAME_RE ) do |i|
+        e = i.size > 2 ? i[2] : 'none'
+        @interwiki_names[i[0]] = {:url => i[1], :encoding => e}
+      end
     end
 
     def interwiki(s, p, display_text = "#{s}:#{p}".escapeHTML)
@@ -26,43 +26,33 @@ module Hiki
                  p.to_sjis.escape
                when 'euc'
                  p.to_euc.escape
+               when 'utf8'
+                 euc_to_utf8(p).escape
                else
                  p
                end
         if encoding == 'alias'
-          @plugin.make_anchor("#{@interwiki_names[s][:url]}", s.escapeHTML)
+          ["#{@interwiki_names[s][:url]}", s.escapeHTML]
         elsif @interwiki_names[s][:url].index('$1')
-          url = @interwiki_names[s][:url].dup.sub(/\$1/, page)
-          @plugin.make_anchor(url, display_text)
+          [@interwiki_names[s][:url].dup.sub(/\$1/, page), display_text]
         else
-          @plugin.make_anchor("#{@interwiki_names[s][:url]}#{page}", display_text)
+          ["#{@interwiki_names[s][:url]}#{page}", display_text]
         end
       else
-        "#{s}:#{p}".escapeHTML
+        nil
       end
     end
 
     def outer_alias(s)
-      a = nil
-      if @interwiki_names.has_key?(s)
-        if @interwiki_names[s][:encoding] == 'alias'
-          a = @plugin.make_anchor(@interwiki_names[s][:url], s.escapeHTML)
-        end
-      end
-      a
-    end
-    
-    private
-    def load_interwiki_names
-      n = @db.load( $interwiki_name ) || ''
-      n.scan( INTERWIKI_NAME_RE ) do |i|
-        e = i.size > 2 ? i[2] : 'none'
-        @interwiki_names[i[0]] = {:url => i[1], :encoding => e}
+      if @interwiki_names.has_key?(s) && @interwiki_names[s][:encoding] == 'alias'
+	return [@interwiki_names[s][:url], s.escapeHTML]
+      else
+	return nil
       end
     end
   end
 end
 
-# *[[Hiki|http://www.namaraii.com/hiki/hiki.cgi?]] euc
+# *[[Hiki|http://hikiwiki.org/ja/?]] euc
 # *[[YukiWiki|http://www.hyuki.com/yukiwiki/wiki.cgi?]] euc
 # *[[GoogleJ|http://www.google.co.jp/search?hl=ja&btnG=Google+%8C%9F%8D%F5&lr=lang_ja&q=]] sjis
