@@ -4,7 +4,7 @@
 
 ;; Author: Hideaki Hori <yowaken@cool.ne.jp>
 
-;; $Id: hiki-mode.el,v 1.4 2005/07/12 04:39:00 fdiary Exp $
+;; $Id: hiki-mode.el,v 1.9 2005/08/03 14:00:21 yanagita Exp $
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -54,7 +54,7 @@
 (require 'derived)
 
 (defconst hiki-mode-version
-  (let ((revision "$Revision: 1.4 $"))
+  (let ((revision "$Revision: 1.9 $"))
     (string-match "\\([0-9.]+\\)" revision)
     (match-string 1 revision)))
 
@@ -79,6 +79,10 @@ Each element looks like (NAME URL STYLE). STYLE is optional.")
 
 (defvar hiki-md5hex nil)
 
+(defvar hiki-session-id nil)
+
+(defvar hiki-update-timestamp nil)
+
 (defvar hiki-edit-newpage nil)
 
 (defvar hiki-password-alist nil)
@@ -149,6 +153,8 @@ is expected to accept only one argument(URL).")
   (make-local-variable 'hiki-newpage)
   (make-local-variable 'hiki-pagename)
   (make-local-variable 'hiki-md5hex)
+  (make-local-variable 'hiki-session-id)
+  (make-local-variable 'hiki-update-timestamp)
   (setq require-final-newline t
 	indent-tabs-mode nil)
   (hiki-edit-setup-keys)
@@ -250,19 +256,19 @@ STRING  non-nil ʤ顢򥵥̾Ȥ롣"
     c))
 
 (defun hiki-http-request (mode cmd pagename site-url &optional post-data)
-  (let (url buf)
-    (setq url (concat (format "%s?c=%s" site-url cmd)
-		      (if pagename 
-			  (format ";p=%s" (hiki-http-url-hexify-string pagename hiki-coding-system)))
-		      ""))
-    (setq buf (hiki-http-fetch url mode nil nil 
-			  (hiki-http-url-hexify-alist post-data hiki-coding-system)))
+  (let* ((url (if (eq mode 'get)
+                  (concat (format "%s?c=%s" site-url cmd)
+                          (if pagename 
+                              (format ";p=%s" (hiki-http-url-hexify-string pagename hiki-coding-system))))
+                site-url))
+         (buf (hiki-http-fetch url mode nil nil 
+                               (hiki-http-url-hexify-alist post-data hiki-coding-system))))
     (if (bufferp buf)
-	(save-excursion
-	  (set-buffer buf)
-	  (decode-coding-region (point-min) (point-max)	hiki-coding-system)
-	  (goto-char (point-min))
-	  buf)
+        (save-excursion
+          (set-buffer buf)
+          (decode-coding-region (point-min) (point-max) hiki-coding-system)
+          (goto-char (point-min))
+          buf)
       (error (format "hiki get: %s - %s" (car buf) (cdr buf))))))
 
 (defun hiki-current-anchor-string ()
@@ -673,8 +679,9 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
 	(hiki-edit-rename-buffer (hiki-site-name site-info) pagename pagetitle password)
 	(save-excursion
 	  (when keyword
-	    (insert (hiki-propertize "Keywords:\n" 'read-only t 'front-sticky t 'rear-nonsticky t 'hiki-special t))
-	    (insert (hiki-propertize (format "%s\n" keyword) 'hiki-keywords t 'hiki-special t))
+	    (insert (hiki-propertize "Keywords:" 'read-only t 'front-sticky t 'rear-nonsticky t 'hiki-special t))
+	    (insert (hiki-propertize "\n" 'hiki-special t))
+	    (insert (hiki-propertize (format "%s\n" keyword) 'hiki-special t))
 	    (insert (hiki-propertize "----\n" 'read-only t 'front-sticky t 'rear-nonsticky t 'hiki-special t)))
 	  (setq point (point))
 	  (insert body)
@@ -694,6 +701,8 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
   (let ((result (hiki-display-page pagename site-info t)))
     (when result
       (setq hiki-md5hex (cdr (assq 'md5hex result)))
+      (setq hiki-session-id (cdr (assq 'session-id result)))
+      (setq hiki-update-timestamp (cdr (assq 'update-timestamp result)))
       (setq hiki-pagename pagename)
       (setq hiki-pagetitle (or (cdr (assq 'pagetitle result)) pagename))
       (setq hiki-site-info site-info)
@@ -707,22 +716,27 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
 (defun hiki-fetch-index (site-info)
   "ڡ롣"
   (let (indexes history (i 1)
-	(buf (hiki-http-request 'get "index" nil (hiki-site-url site-info))))
+                (buf (hiki-http-request 'get "index" nil (hiki-site-url site-info))))
     (when (bufferp buf)
       (save-excursion
-	(set-buffer buf)
-	(re-search-forward "<ul>\n\\s-*" nil t nil)
-	(while (equal (char-after) ?<)
-	  (re-search-forward "<a[^?]*\\?\\([^\"]*\\)\"[^>]*>\\([^<]*\\)</a>: \\([^<]*\\)</li>" nil t nil)
-	  (setq indexes 
-		(cons
-		 (list i (hiki-http-url-unhexify-string (match-string 1) hiki-coding-system)
-
-		       (hiki-replace-entity-refs (match-string 2))
-		       (hiki-replace-entity-refs (match-string 3))) indexes))
-	  (setq i (1+ i))))
+        (set-buffer buf)
+        (re-search-forward "<ul>\n\\s-*" nil t nil)
+        (while (and (equal (char-after) ?<)
+                    (re-search-forward "<a href=\"\\([^\"]*\\)\">\\([^<]*\\)</a>: \\([^<]*\\)</li>" nil t nil))
+          (let ((page-url (match-string 1))
+                (page-title (match-string 2))
+                (page-description (match-string 3)))
+            (setq indexes 
+                  (cons
+                   (list i (hiki-http-url-unhexify-string (if (string-match "\\?\\(.*\\)" page-url)
+                                                              (match-string 1 page-url)
+                                                            "FrontPage")
+                                                          hiki-coding-system)
+                         (hiki-replace-entity-refs page-title)
+                         (hiki-replace-entity-refs page-description)) indexes)))
+          (setq i (1+ i))))
       (or (setq history (assoc (hiki-site-name site-info) hiki-pagename-history))
-	  (setq hiki-pagename-history (cons (setq history (cons (hiki-site-name site-info) nil)) hiki-pagename-history)))
+          (setq hiki-pagename-history (cons (setq history (cons (hiki-site-name site-info) nil)) hiki-pagename-history)))
       (setcdr history (mapcar (lambda (elm) (cons (nth 1 elm) nil)) indexes))
       (reverse indexes))))
 
@@ -730,9 +744,11 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
   "Hiki  롣
 
 '((md5hex . \"...\")
+  (session-id . \"...\")
   (body . \"...\")
   (pagetitle . (...)) 
   (keyword . (...)) 
+  (update-timestamp . t/nil)
   (password . t/nil)) ֤"
   (let (buf start end pt result)
     (setq buf (hiki-http-request 'get "edit" pagename site-url))
@@ -742,9 +758,12 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
 	;; md5hex
 	(re-search-forward "<input [^>]+name=\"md5hex\" value=\"\\([^>\"]*\\)\">" nil t nil)
 	(setq result (cons (cons 'md5hex (match-string 1)) result))
+	;; session id
+	(re-search-forward "<input [^>]+name=\"session_id\" value=\"\\([^>\"]*\\)\">" nil t nil)
+	(setq result (cons (cons 'session-id (match-string 1)) result))
 	(setq pt (point))
 	;; textarea
-	(re-search-forward "<textarea [^>]+name=\"contents\"[^>]+>" nil t nil)
+	(re-search-forward "<textarea [^>]+name=\"contents\"[^>]*>" nil t nil)
 	(setq start (match-end 0))
 	(re-search-forward "</textarea>" nil t nil)
 	(setq end (match-beginning 0))
@@ -753,6 +772,10 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
 	(goto-char pt)
 	(re-search-forward "<input [^>]+name=\"page_title\" [^>]+value=\"\\([^>\"]*\\)\">" nil t nil)
 	(setq result (cons (cons 'pagetitle (hiki-replace-entity-refs (match-string 1))) result))
+	;; update timestamp?
+	(if (re-search-forward "<input type=\"checkbox\" name=\"update_timestamp\" value=\"on\" checked>" nil t nil)
+	    (setq result (cons (cons 'update-timestamp t) result))
+	  (setq result (cons (cons 'update-timestamp nil) result)))
 	;; keyword
 	(when (re-search-forward "<textarea [^>]+name=\"keyword\" [^>]+>" nil t nil)
 	  (setq start (match-end 0))
@@ -775,17 +798,22 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
 		     (or hiki-pagetitle hiki-pagename) nil nil nil (or hiki-pagetitle hiki-pagename)))
     (goto-char (point-min))
     (when (get-text-property (point) 'hiki-special)
-      (goto-char (next-single-property-change (point) 'hiki-keywords))
-      (setq keywords 
-	    (buffer-substring-no-properties (point) (next-single-property-change (point) 'hiki-keywords)))
+      (re-search-forward "^Keywords:$" nil t nil)
+      (let (start end)
+        (setq start (+ (match-end 0) 1))
+        (re-search-forward "^----$" nil t nil)
+        (setq end (match-beginning 0))
+        (setq keywords (buffer-substring-no-properties start end)))
       (goto-char (next-single-property-change (point) 'hiki-special)))
-    (setq contents (buffer-substring (point) (point-max)))
+    (setq contents (buffer-substring-no-properties (point) (point-max)))
     (add-to-list 'post-data (cons "c" "save"))
     (add-to-list 'post-data (cons "p" hiki-pagename))
     (add-to-list 'post-data (cons "page_title" pagetitle))
     (add-to-list 'post-data (cons "keyword" (or keywords "")))
     (add-to-list 'post-data (cons "md5hex" hiki-md5hex))
-    (add-to-list 'post-data (cons "password" password))
+    (add-to-list 'post-data (cons "session_id" hiki-session-id))
+    (if (not (null hiki-update-timestamp))
+	(add-to-list 'post-data (cons "update_timestamp" "on")))
     (if (not (null hiki-freeze))
 	(add-to-list 'post-data (cons "freeze" "on")))
     (add-to-list 'post-data (cons "contents" contents))
@@ -1064,11 +1092,20 @@ If error, return a cons cell (ERRCODE . DESCRIPTION)."
                      buf)
 		    ((equal code "302")
 		     buf)
+		    ((equal code "404")
+		     (cons code (hiki-get-error-message buf)))
 		    (t
                      (cons code desc)))))))))
 
 (defun hiki-http-cookie-expired ()
   (setq hiki-http-cookie nil))
 
+(defun hiki-get-error-message (buf)
+  (set-buffer buf)
+  (re-search-forward "<h1 class=\"header\">Error</h1>" nil t nil)
+  (goto-char (match-end 0))
+  (re-search-forward "<div>\\([^<]+\\)</div>" nil t nil)
+  (match-string 1))
+
 (provide 'hiki-mode)
 ;;; hiki-mode.el ends here
