@@ -1,4 +1,4 @@
-# $Id: html_formatter.rb,v 1.39 2005/07/13 01:43:06 fdiary Exp $
+# $Id: html_formatter.rb,v 1.42 2005/07/26 13:59:15 yanagita Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 require 'hiki/util'
@@ -160,6 +160,7 @@ module Hiki
       when :interwiki
         if inter_link = @interwiki.interwiki(t[:href], t[:p], t[:s])
           s[:html] << @plugin.make_anchor(inter_link[0], inter_link[1], 'external')
+	  s[:toc_title] << t[:s] if s[:toc_level] > 0
         else
           t[:href] = t[:s]
           make_link(t, s)
@@ -277,7 +278,7 @@ EOS
       str = t[:method].gsub(/&/, '&amp;').gsub(/</, '&lt;').gsub(/>/, '&gt;')
       case t[:e]
       when :inline_plugin
-	@plugin.inline_context{ apply_plugin( str, @plugin, @conf ) }
+        @plugin.inline_context{ apply_plugin( str, @plugin, @conf ) }
       else
         @plugin.block_context{ apply_plugin( str, @plugin, @conf ) }
       end
@@ -300,12 +301,12 @@ EOS
         if outer_alias = @interwiki.outer_alias(t[:href])
           s[:html] << @plugin.make_anchor(outer_alias[0], outer_alias[1], 'external')
         else
-          missing_anchor_title = @conf.msg_missing_anchor_title % [ disp.escapeHTML ]
+          missing_anchor_title = @conf.msg_missing_anchor_title % [ t[:href].escapeHTML ]
           wikiname_anchor = @plugin.creatable? ? "#{disp.escapeHTML}<a class=\"nodisp\" href=\"#{@conf.cgi_name}?c=edit;p=#{t[:href].escape}\" title=\"#{missing_anchor_title}\">?</a>" : disp.escapeHTML
           s[:html] << wikiname_anchor
         end
       end
-      s[:toc_title] << t[:href] if s[:toc_level] > 0
+      s[:toc_title] << disp if s[:toc_level] > 0
     end
   end
 end
